import React, { useState } from 'react';

interface GlitchyLinkProps {
    text: string;
    url: string;
    type?: 'email' | 'link';
}

const GlitchyLink: React.FC<GlitchyLinkProps> = ({ text, url, type = 'link' }) => {
    const [copied, setCopied] = useState(false);

    const handleClick = async (e: React.MouseEvent) => {
        if (type === 'email') {
            e.preventDefault();
            if (copied) return;
            await navigator.clipboard.writeText(text);
            setCopied(true);
            setTimeout(() => setCopied(false), 2000);
        }
    };

    return (
        <a
            href={url}
            target="_blank"
            rel="noopener noreferrer"
            onClick={handleClick}
            className="group relative inline-block hover:text-green-400 transition-colors"
        >
            <span className="relative inline-block animate-glitch-1">
                {copied ? 'Copied!' : text}
            </span>
            <span className="absolute top-0 left-0 w-full h-full opacity-0 group-hover:opacity-70 group-hover:animate-glitch-1">
                {copied ? 'Copied!' : text}
            </span>
            <span className="absolute top-0 left-0 w-full h-full opacity-0 group-hover:opacity-70 group-hover:animate-glitch-2">
                {copied ? 'Copied!' : text}
            </span>
        </a>
    );
};

export default GlitchyLink;
