import { FileSystem } from "./FileSystem";
import axios from 'axios';

export class ShellSyscall {
    constructor(
        private fs: FileSystem,
        private cwd: string
    ) {}

    getCurrentDirectory(): string {
        return this.cwd;
    }

    listCurrentDirectory(): string[] {
        return this.fs.listDirectory(this.cwd);
    }

    changeDirectory(path: string): boolean {
        // For now, just accept any path
        this.cwd = path;
        return true;
    }

    createFile(filename: string): void {
        this.fs.writeFile(`${this.cwd}/${filename}`, '');
    }

    readFile(filename: string): string {
        return this.fs.readFile(`${this.cwd}/${filename}`) || '';
    }

    writeFile(filename: string, content: string) {
        this.fs.writeFile(`${this.cwd}/${filename}`, content);
    }

    async fetchUrl(url: string) {
        return await axios.get(url);
    }

    deleteFile(path: string): void {
        this.fs.deleteFile(`${this.cwd}/${path}`);
    }

    createDirectory(dirname: string): void {
        this.fs.createDirectory(`${this.cwd}/${dirname}`);
    }
}
